@@ -1,7 +1,7 @@
 from .repo import *
 
 
-def load(source_dir: str = None) -> Repo:
+def load(sample_programs_repo_dir: Optional[str] = None, sample_programs_website_repo_dir: Optional[str] = None) -> Repo:
     """
     Loads the Sample Programs repo as a Repo object. This is
     a convenience function which can be used to quickly generate
@@ -14,8 +14,11 @@ def load(source_dir: str = None) -> Repo:
     Optionally, you can also provide a source directory which
     bypasses the need for git on your system::
 
-        repo = subete.load(source_dir="path/to/sample-programs/archive")
+        repo = subete.load(sample_programs_repo_dir="path/to/sample-programs/archive")
 
     :return: the Sample Programs repo as a Repo object
     """
-    return Repo(source_dir=source_dir)
+    return Repo(
+        sample_programs_repo_dir=sample_programs_repo_dir,
+        sample_programs_website_repo_dir=sample_programs_website_repo_dir
+    )
